/*
    SPDX-FileCopyrightText: 2007 Paolo Capriotti <p.capriotti@gmail.com>

    SPDX-License-Identifier: GPL-2.0-or-later
*/

#ifndef SPRITEFWD_H
#define SPRITEFWD_H

#include <QExplicitlySharedDataPointer>

class Sprite;

typedef QExplicitlySharedDataPointer<Sprite> SpritePtr;

#endif // SPRITEFWD_H

