<?xml version="1.0" encoding="UTF-8"?>
<gui name="kollision"
     version="2"
     xmlns="http://www.kde.org/standards/kxmlgui/1.0"
     xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
     xsi:schemaLocation="http://www.kde.org/standards/kxmlgui/1.0
                         http://www.kde.org/standards/kxmlgui/1.0/kxmlgui.xsd">
    <MenuBar>
        <Menu name="game"><text>&amp;Game</text>
            <Action name="game_abort" append="new_merge" />
        </Menu>
        <Menu name="settings">
            <Action name="options_sounds" />
            <Action name="increase_ball_size" />
        </Menu>
    </MenuBar>
    <State name="playing">
        <enable>
            <Action name="game_abort" />
            <Action name="game_pause" />
        </enable>
    </State>
</gui>
